@@ -9,7 +9,7 @@ pub fn register(manager: &mut BuildToolManager) {
 }
 
 #[derive(Debug)]
-pub(crate) struct NpmProbe;
+pub struct NpmProbe;
 
 impl BuildToolProbe for NpmProbe {
     fn probe(&self, path: &Utf8Path) -> Option<Box<dyn BuildTool>> {
@@ -30,7 +30,7 @@ impl BuildToolProbe for NpmProbe {
 }
 
 #[derive(Debug)]
-pub(crate) struct Npm {
+pub struct Npm {
     path: Utf8PathBuf,
 }
 
@@ -39,7 +39,6 @@ impl BuildTool for Npm {
         let deps_dir = self.path.join("node_modules");
         if deps_dir.exists() {
             assert!(deps_dir.is_dir());
-            assert!(deps_dir.join(".package-lock.json").is_file());
             if dry_run {
                 println!("{}: rm -r {deps_dir}", self.path);
             } else {
